@@ -1,4 +1,4 @@
-/* $Id: gdict-applet.c,v 1.41 2003/05/18 17:15:52 dcransto Exp $ */
+/* $Id: gdict-applet.c,v 1.43 2003/05/31 06:03:27 dcransto Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -215,7 +215,7 @@ help_cb (BonoboUIComponent *uic,
 		dialog = gtk_message_dialog_new (NULL,
 						 GTK_DIALOG_MODAL,
 						 GTK_MESSAGE_ERROR,
-						 GTK_BUTTONS_CLOSE,
+						 GTK_BUTTONS_OK,
 						 ("There was an error displaying help: \n%s"),
 						 error->message);
 
@@ -239,23 +239,6 @@ prefs_cb (BonoboUIComponent *uic,
 	gdict_app_show_preferences ();
 }
 
-static void
-spell_cb (BonoboUIComponent *uic,
-          gpointer           user_data,
-          const gchar       *verbname)
-{
-	GDictApplet *applet = user_data;
-	gchar *text;
-	
-	if (!context)
-		gdict_init_context ();
-#ifdef FIXME
-	text = gtk_editable_get_chars (GTK_EDITABLE (applet->entry_widget), 0, -1);
-    	gdict_spell (text, FALSE);
-        g_free (text);
-#endif
-}
-
 static const BonoboUIVerb gdict_applet_menu_verbs [] = {
 	BONOBO_UI_VERB ("sel", lookup_selected_text),
         BONOBO_UI_VERB ("prefs", prefs_cb),
