@@ -1,4 +1,4 @@
-/* $Id: gdict-pref-dialog.c,v 1.31.2.1 2002/07/15 21:58:33 gman Exp $ */
+/* $Id: gdict-pref-dialog.c,v 1.36 2003/05/31 06:03:27 dcransto Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -33,17 +33,6 @@ enum {
     LAST_SIGNAL
 };
 
-static gchar *typeface_sel_names[NUM_TYPEFACES] = {
-    N_("Headword:"),
-    N_("Sub-number:"),
-    N_("Pronunciation:"),
-    N_("Etymology:"),
-    N_("Part of speech:"),
-    N_("Example:"),
-    N_("Main body:"),
-    N_("Cross-reference:")
-};
-
 #define NUM_TYPEFACE_ROWS 4
 #define NUM_TYPEFACE_COLS 2
 
@@ -64,8 +53,6 @@ static void pref_dialog_add_strat   (GDictPrefDialog *pref_dialog,
                                      gchar *strat, gchar *desc);
 static void pref_dialog_reset_db    (GDictPrefDialog *pref_dialog);
 static void pref_dialog_reset_strat (GDictPrefDialog *pref_dialog);
-static gint pref_dialog_update_pref (GDictPrefDialog *pref_dialog,
-                                     gboolean save_prefs);
 
 static void pref_set_strat_cb       (GtkWidget *widget, gpointer data);
 static void pref_set_db_cb          (GtkWidget *widget, gpointer data);
@@ -79,9 +66,6 @@ static void pref_status_cb          (dict_command_t *command,
 static void pref_data_cb            (dict_command_t *command, dict_res_t *res,
                                      gpointer data);
 
-static void pref_dialog_ok_cb       (GtkWidget *widget, gpointer data);
-static void pref_dialog_apply_cb    (GtkWidget *widget, gpointer data);
-static void pref_dialog_close_cb    (GtkWidget *widget, gpointer data);
 static void phelp_cb		    (GtkDialog *dialog, gint response);
 static void response_cb		    (GtkDialog *dialog, gint response);
 static gboolean	set_server_cb 	    (GtkWidget *widget, GdkEventFocus *event, gpointer data);
@@ -174,25 +158,25 @@ gdict_pref_dialog_class_init (GDictPrefDialogClass *class)
 static void
 create_dialog (GDictPrefDialog *pref_dialog)
 {
-    GtkWidget *server_label, *port_label, *alignment;
-    GtkWidget *vbox, *table;
+    GtkWidget *server_label, *port_label;
+    GtkWidget *vbox;
     GtkWidget *button;    
     gchar *port_str;
-    gint i;
     
     pref_dialog->database = gdict_pref.database;
     pref_dialog->dfl_strat = gdict_pref.dfl_strat;
     
     gtk_window_set_title (GTK_WINDOW (pref_dialog), _("Dictionary Preferences"));
     gtk_window_set_policy (GTK_WINDOW (pref_dialog), FALSE, FALSE, FALSE);    
+    gtk_container_set_border_width (GTK_CONTAINER (pref_dialog), 5);
     vbox = GTK_DIALOG (pref_dialog)->vbox;
 
     
     pref_dialog->table = GTK_TABLE (gtk_table_new (5, 3, FALSE));
     gtk_box_pack_start (GTK_BOX (GTK_DIALOG (pref_dialog)->vbox), GTK_WIDGET (pref_dialog->table), TRUE, TRUE, 0);
-    gtk_container_set_border_width (GTK_CONTAINER (pref_dialog->table), 8);
+    gtk_container_set_border_width (GTK_CONTAINER (pref_dialog->table), 5);
     gtk_table_set_row_spacings (pref_dialog->table, 6);
-    gtk_table_set_col_spacings (pref_dialog->table, 6);
+    gtk_table_set_col_spacings (pref_dialog->table, 12);
 
     pref_dialog->smart_lookup_btn = 
         GTK_CHECK_BUTTON (gtk_check_button_new_with_mnemonic (_("Smart _lookup")));
@@ -201,22 +185,28 @@ create_dialog (GDictPrefDialog *pref_dialog)
     gtk_table_attach_defaults (pref_dialog->table, GTK_WIDGET (pref_dialog->smart_lookup_btn),
     			       1, 3, 2, 3);
     
-    pref_dialog->server_entry = GTK_ENTRY (gtk_entry_new ());
-    gtk_table_attach_defaults (pref_dialog->table, 
-                               GTK_WIDGET (pref_dialog->server_entry), 
-                               1, 2, 0, 1);
+    pref_dialog->server_entry = GTK_ENTRY (gtk_entry_new ());			       
+    gtk_table_attach (pref_dialog->table, 
+                      GTK_WIDGET (pref_dialog->server_entry),
+                      1, 2, 0, 1,
+                      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+                      (GtkAttachOptions) (0), 0, 0);
+		    
     g_signal_connect (G_OBJECT (pref_dialog->server_entry), "focus_out_event",
     		      G_CALLBACK (set_server_cb), pref_dialog);
     
     server_label = gtk_label_new_with_mnemonic (_("_Server:"));
     gtk_label_set_mnemonic_widget (GTK_LABEL (server_label), 
     				   GTK_WIDGET (pref_dialog->server_entry));
-    gtk_label_set_justify (GTK_LABEL (server_label), GTK_JUSTIFY_RIGHT);
-    gtk_misc_set_alignment (GTK_MISC (server_label), 1, 0.5);
+    gtk_label_set_justify (GTK_LABEL (server_label), GTK_JUSTIFY_LEFT);
+    gtk_misc_set_alignment (GTK_MISC (server_label), 0, 0.5);
     gtk_table_attach_defaults (pref_dialog->table, server_label, 0, 1, 0, 1);
     
-    button = gtk_button_new_with_mnemonic (_("De_fault"));
-    gtk_table_attach_defaults (pref_dialog->table, button, 2, 3, 0, 1);
+    button = gtk_button_new_with_mnemonic (_("De_fault Server"));
+    gtk_table_attach (pref_dialog->table, 
+                      button, 2, 3, 0, 1,
+                      (GtkAttachOptions) (GTK_FILL),
+                      (GtkAttachOptions) (0), 0, 0);
     g_signal_connect (G_OBJECT (button), "clicked",
     		      G_CALLBACK (set_default_server), pref_dialog);
 
@@ -225,20 +215,25 @@ create_dialog (GDictPrefDialog *pref_dialog)
 
     port_label = gtk_label_new_with_mnemonic (_("_Port:"));
     gtk_table_attach_defaults (pref_dialog->table, port_label, 0, 1, 1, 2);
-    gtk_label_set_justify (GTK_LABEL (port_label), GTK_JUSTIFY_RIGHT);
-    gtk_misc_set_alignment (GTK_MISC (port_label), 1, 0.5);
+    gtk_label_set_justify (GTK_LABEL (port_label), GTK_JUSTIFY_LEFT);
+    gtk_misc_set_alignment (GTK_MISC (port_label), 0, 0.5);
 
     pref_dialog->port_entry = GTK_ENTRY (gtk_entry_new ());
     gtk_label_set_mnemonic_widget (GTK_LABEL (port_label), 
     				   GTK_WIDGET (pref_dialog->port_entry));
-    gtk_table_attach_defaults (pref_dialog->table, 
-                               GTK_WIDGET (pref_dialog->port_entry), 
-                               1, 2, 1, 2);
+    gtk_table_attach (pref_dialog->table, 
+                      GTK_WIDGET (pref_dialog->port_entry),
+                      1, 2, 1, 2,
+                      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+                      (GtkAttachOptions) (0), 0, 0);
     g_signal_connect (G_OBJECT (pref_dialog->port_entry), "focus_out_event",
     		      G_CALLBACK (set_port_cb), pref_dialog);
                                
-    button = gtk_button_new_with_mnemonic (_("Def_ault"));
-    gtk_table_attach_defaults (pref_dialog->table, button, 2, 3, 1, 2);
+    button = gtk_button_new_with_mnemonic (_("Def_ault Port"));
+    gtk_table_attach (pref_dialog->table, 
+                      button, 2, 3, 1, 2,
+                      (GtkAttachOptions) (GTK_FILL),
+                      (GtkAttachOptions) (0), 0, 0);
     g_signal_connect (G_OBJECT (button), "clicked",
     		      G_CALLBACK (set_default_port), pref_dialog);
     
@@ -256,15 +251,15 @@ create_dialog (GDictPrefDialog *pref_dialog)
     }
 
     db_label = gtk_label_new_with_mnemonic (_("_Database:"));
-    gtk_label_set_justify (GTK_LABEL (db_label), GTK_JUSTIFY_RIGHT);
-    gtk_misc_set_alignment (GTK_MISC (db_label), 1, 0.5);
+    gtk_label_set_justify (GTK_LABEL (db_label), GTK_JUSTIFY_LEFT);
+    gtk_misc_set_alignment (GTK_MISC (db_label), 0, 0.5);
     gtk_table_attach_defaults (pref_dialog->table, db_label, 0, 1, 3, 4);
     pref_dialog->db_list = GTK_MENU (gtk_menu_new ());
     gtk_widget_show (GTK_WIDGET (pref_dialog->db_list));
     
     strat_label = gtk_label_new_with_mnemonic (_("D_efault strategy:"));
-    gtk_label_set_justify (GTK_LABEL (strat_label), GTK_JUSTIFY_RIGHT);
-    gtk_misc_set_alignment (GTK_MISC (strat_label), 1, 0.5);
+    gtk_label_set_justify (GTK_LABEL (strat_label), GTK_JUSTIFY_LEFT);
+    gtk_misc_set_alignment (GTK_MISC (strat_label), 0, 0.5);
     gtk_table_attach_defaults (pref_dialog->table, strat_label, 0, 1, 4, 5);
     pref_dialog->strat_list = GTK_MENU (gtk_menu_new ());
     gtk_widget_show (GTK_WIDGET (pref_dialog->strat_list));
@@ -275,6 +270,7 @@ create_dialog (GDictPrefDialog *pref_dialog)
     			    GTK_RESPONSE_CLOSE, GTK_STOCK_HELP, GTK_RESPONSE_HELP, NULL);  
 
     gtk_dialog_set_default_response (GTK_DIALOG (pref_dialog), GTK_RESPONSE_CLOSE);
+    gtk_dialog_set_has_separator (GTK_DIALOG (pref_dialog), FALSE);
     
     g_signal_connect (G_OBJECT (pref_dialog), "response",
     		      G_CALLBACK (response_cb), NULL);
@@ -305,7 +301,6 @@ GtkWidget *
 gdict_pref_dialog_new (dict_context_t *context) 
 {
     GDictPrefDialog *pref_dialog;
-    GtkLabel *label;
     
     /* g_return_val_if_fail (context != NULL, NULL); */
     /* the above is commented out because it prints ugly debug messages
@@ -426,7 +421,6 @@ pref_dialog_add_strat (GDictPrefDialog *pref_dialog, gchar *strat,
 
 static void
 pref_dialog_reset_db (GDictPrefDialog *pref_dialog) {
-    GtkWidget *error_label, *alignment;
 
     if (pref_dialog->get_db_cmd)
       dict_command_destroy (pref_dialog->get_db_cmd);
@@ -479,7 +473,6 @@ pref_dialog_reset_db (GDictPrefDialog *pref_dialog) {
 
 static void
 pref_dialog_reset_strat (GDictPrefDialog *pref_dialog) {
-    GtkWidget *error_label, *alignment;
 
     if (pref_dialog->get_strat_cmd)
 	dict_command_destroy (pref_dialog->get_strat_cmd);
@@ -543,7 +536,7 @@ pref_error_cb (dict_command_t *command, DictStatusCode code,
         GtkWidget *dialog;
         dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
                                   	 GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-                                  	 "%s", message, NULL); 
+                                  	 "%s", message); 
 	gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
     }
@@ -687,7 +680,6 @@ set_port_cb (GtkWidget *widget, GdkEventFocus *event, gpointer data)
 {
     GDictPrefDialog *pref_dialog = data;
     gchar *port;
-    gint old_port;
     
     port = gtk_editable_get_chars (GTK_EDITABLE (pref_dialog->port_entry), 0, -1);
     
@@ -737,7 +729,6 @@ set_default_port (GtkButton *button, gpointer data)
 static void 
 smart_lookup_cb	(GtkToggleButton *toggle, gpointer data)
 {
-    GDictPrefDialog *pref_dialog = data;
     gboolean toggled;
     
     toggled = gtk_toggle_button_get_active (toggle);
@@ -760,7 +751,7 @@ phelp_cb    (GtkDialog *dialog, gint response)
 		msg_dialog = gtk_message_dialog_new (GTK_WINDOW(dialog),
 						     GTK_DIALOG_DESTROY_WITH_PARENT,
 						     GTK_MESSAGE_ERROR,
-						     GTK_BUTTONS_CLOSE,
+						     GTK_BUTTONS_OK,
 						     ("There was an error displaying help: \n%s"),
 						     error->message);
 
