@@ -30,6 +30,11 @@
 #define GNOME_SEARCH_TOOL_STOCK "panel-searchtool"
 #define LEFT_LABEL_SPACING "     "
 
+#define DEFAULT_ANIMATION_WIDTH   48
+#define DEFAULT_ANIMATION_HEIGHT  48
+#define DEFAULT_ANIMATION_FRAME    2
+#define TOTAL_ANIMATION_FRAMES     3
+
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -65,12 +70,12 @@ struct _FindOptionTemplate {
 };
 	
 static FindOptionTemplate templates[] = {
-	{ SEARCH_CONSTRAINT_TEXT, "-exec grep -c '%s' {} \\;", N_("C_ontains the text"), FALSE },
+	{ SEARCH_CONSTRAINT_TEXT, "-exec grep -c '%s' {} \\;", N_("Contains the _text"), FALSE },
 	{ SEARCH_CONSTRAINT_SEPARATOR, NULL, NULL, TRUE },
 	{ SEARCH_CONSTRAINT_TIME, "-mtime -%d", N_("_Date modified less than (days)"), FALSE },
-	{ SEARCH_CONSTRAINT_TIME, "-mtime +%d", N_("Da_te modified more than (days)"), FALSE },
+	{ SEARCH_CONSTRAINT_TIME, "-mtime +%d", N_("Date modified more than (da_ys)"), FALSE },
 	{ SEARCH_CONSTRAINT_SEPARATOR, NULL, NULL, TRUE },
-	{ SEARCH_CONSTRAINT_NUMBER, "-size +%uc", N_("_Size at least (kilobytes)"), FALSE }, 
+	{ SEARCH_CONSTRAINT_NUMBER, "-size +%uc", N_("S_ize at least (kilobytes)"), FALSE }, 
 	{ SEARCH_CONSTRAINT_NUMBER, "-size -%uc", N_("Si_ze at most (kilobytes)"), FALSE },
 	{ SEARCH_CONSTRAINT_BOOL, "-size 0c \\( -type f -o -type d \\)", N_("File is empty"), FALSE },	
 	{ SEARCH_CONSTRAINT_SEPARATOR, NULL, NULL, TRUE },
@@ -306,13 +311,16 @@ build_search_command (void)
 	if (GTK_WIDGET_VISIBLE(interface.additional_constraints) == FALSE) {
 	
 		gchar *locate;
+		gboolean disable_quick_search;
 		
 		locate = g_find_program_in_path ("locate");
 		file_is_named_escaped = escape_single_quotes (file_is_named_locale);
 		search_command.file_is_named_pattern = g_strdup(file_is_named_utf8);
+		disable_quick_search = gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/disable_quick_search");
 		
-		if ((locate != NULL) && (is_path_in_home_folder (look_in_folder_locale) != TRUE) 
-		     && (is_path_in_mount_folder (look_in_folder_locale) != TRUE)) {	
+		if ((disable_quick_search != TRUE) && (locate != NULL) 
+		    && (is_path_in_home_folder (look_in_folder_locale) != TRUE) 
+		    && (is_path_in_mount_folder (look_in_folder_locale) != TRUE)) {	
 			g_string_append_printf (command, "%s %s '%s*%s'", 
 						locate,
 						locate_command_default_options,
@@ -429,7 +437,7 @@ add_file_to_search_results (const gchar 	*file,
 	gchar *icon_path = get_file_icon_with_mime_type (file, mime_type);
 	GnomeVFSFileInfo *vfs_file_info = gnome_vfs_file_info_new ();
 	GdkPixbuf *pixbuf = NULL;
-	gchar *readable_size, *readable_date, *date;
+	gchar *readable_size, *readable_date;
 	gchar *utf8_base_name, *utf8_dir_name;
 	gchar *base_name, *dir_name;
 	
@@ -467,7 +475,6 @@ add_file_to_search_results (const gchar 	*file,
 	gnome_vfs_get_file_info (file, vfs_file_info, GNOME_VFS_FILE_INFO_DEFAULT);
 	readable_size = gnome_vfs_format_file_size_for_display (vfs_file_info->size);
 	readable_date = get_readable_date (vfs_file_info->mtime);
-	date = get_date (vfs_file_info->mtime);
 	
 	base_name = g_path_get_basename (file);
 	dir_name = g_path_get_dirname (file);
@@ -481,10 +488,10 @@ add_file_to_search_results (const gchar 	*file,
 			    COLUMN_NAME, utf8_base_name,
 			    COLUMN_PATH, utf8_dir_name,
 			    COLUMN_READABLE_SIZE, readable_size,
-			    COLUMN_SIZE, (gdouble) vfs_file_info->size,
+			    COLUMN_SIZE, (-1) * (gdouble) vfs_file_info->size,
 			    COLUMN_TYPE, description,
 			    COLUMN_READABLE_DATE, readable_date,
-			    COLUMN_DATE, date,
+			    COLUMN_DATE, (-1) * (gdouble) vfs_file_info->mtime,
 			    COLUMN_NO_FILES_FOUND, FALSE,
 			    -1);
 
@@ -501,7 +508,6 @@ add_file_to_search_results (const gchar 	*file,
 	g_free (icon_path); 
 	g_free (readable_size);
 	g_free (readable_date);
-	g_free (date);
 }
 
 static void
@@ -520,7 +526,7 @@ add_no_files_found_message (GtkListStore 	*store,
 			    COLUMN_SIZE, (gdouble) 0,
 			    COLUMN_TYPE, "",
 		    	    COLUMN_READABLE_DATE, "",
-		    	    COLUMN_DATE, 0,
+		    	    COLUMN_DATE, (gdouble) 0,
 			    COLUMN_NO_FILES_FOUND, TRUE,
 		    	    -1);
 }
@@ -548,8 +554,8 @@ make_list_of_templates (void)
 			gtk_widget_show (menuitem);
 		} 
 		else {
-			gchar *text = remove_mnemonic_character (templates[i].desc);
-			menuitem = gtk_radio_menu_item_new_with_label (group, _(text));
+			gchar *text = remove_mnemonic_character (_(templates[i].desc));
+			menuitem = gtk_radio_menu_item_new_with_label (group, text);
 			g_signal_connect (G_OBJECT(menuitem), "toggled",
 					  G_CALLBACK(constraint_menu_toggled_cb),
 		        		  (gpointer)(long)i);
@@ -702,24 +708,6 @@ set_constraint_gconf_boolean (gint constraint_id, gboolean flag)
 	}
 }
 
-static void
-setup_app_progress_bar (void)
-{
-	interface.status_bar = gnome_appbar_new (TRUE, TRUE, GNOME_PREFERENCES_NEVER);
-	gnome_app_set_statusbar (GNOME_APP(interface.main_window), interface.status_bar);
-	interface.progress_bar = GTK_WIDGET(gnome_appbar_get_progress (GNOME_APPBAR(interface.status_bar)));
-	g_object_set (G_OBJECT(interface.progress_bar), "pulse_step", 0.1, NULL);
-}
-
-gboolean
-update_progress_bar (gpointer data)
-{
-	if (GTK_IS_PROGRESS_BAR(interface.progress_bar) == TRUE) {
-		gtk_progress_bar_pulse (GTK_PROGRESS_BAR (interface.progress_bar));
-	}
-	return TRUE;
-}
-
 /*
  * add_atk_namedesc
  * @widget    : The Gtk Widget for which @name and @desc are added.
@@ -778,6 +766,204 @@ add_atk_relation (GtkWidget 		*obj1,
 	
 }
 
+gchar *
+get_desktop_item_name (void)
+{
+
+	GString *gs;
+	gchar *file_is_named_utf8;
+	gchar *file_is_named_locale;
+	gchar *look_in_folder_utf8;
+	gchar *look_in_folder_locale;
+	GList *list;
+	
+	gs = g_string_new ("");
+	g_string_append (gs, _("Search for Files"));
+	g_string_append (gs, " (");
+	
+	file_is_named_utf8 = (gchar *) gtk_entry_get_text (GTK_ENTRY(gnome_entry_gtk_entry (GNOME_ENTRY(interface.file_is_named_entry))));
+	file_is_named_locale = g_locale_from_utf8 (file_is_named_utf8 != NULL ? file_is_named_utf8 : "" , 
+	                                           -1, NULL, NULL, NULL);
+	g_string_append (gs, g_strdup_printf ("named=%s", file_is_named_locale));
+	g_free (file_is_named_locale);
+
+	look_in_folder_utf8 = gnome_file_entry_get_full_path (GNOME_FILE_ENTRY(interface.look_in_folder_entry), FALSE);
+	look_in_folder_locale = g_locale_from_utf8 (look_in_folder_utf8 != NULL ? look_in_folder_utf8 : "", 
+	                                            -1, NULL, NULL, NULL);
+	g_string_append (gs, g_strdup_printf ("&path=%s", look_in_folder_locale));
+	g_free (look_in_folder_locale); 
+
+	if (GTK_WIDGET_VISIBLE(interface.additional_constraints) == TRUE) {
+		for (list = interface.selected_constraints; list != NULL; list = g_list_next (list)) {
+			SearchConstraint *constraint = list->data;
+			gchar *locale = NULL;
+			
+			switch (constraint->constraint_id) {
+			case SEARCH_CONSTRAINT_CONTAINS_THE_TEXT:
+				locale = g_locale_from_utf8 (constraint->data.text, -1, NULL, NULL, NULL);
+				g_string_append (gs, g_strdup_printf ("&contains=%s", locale));
+				break;
+			case SEARCH_CONSTRAINT_DATE_MODIFIED_BEFORE:
+				g_string_append (gs, g_strdup_printf ("&mtimeless=%d", constraint->data.time));
+				break;
+			case SEARCH_CONSTRAINT_DATE_MODIFIED_AFTER:
+				g_string_append (gs, g_strdup_printf ("&mtimemore=%d", constraint->data.time));
+				break;
+			case SEARCH_CONSTRAINT_SIZE_IS_MORE_THAN:
+				g_string_append (gs, g_strdup_printf ("&sizemore=%u", constraint->data.number));
+				break;
+			case SEARCH_CONSTRAINT_SIZE_IS_LESS_THAN:
+				g_string_append (gs, g_strdup_printf ("&sizeless=%u", constraint->data.number));
+				break;
+			case SEARCH_CONSTRAINT_FILE_IS_EMPTY:
+				g_string_append (gs, g_strdup ("&empty"));
+				break;
+			case SEARCH_CONSTRAINT_OWNED_BY_USER:
+				locale = g_locale_from_utf8 (constraint->data.text, -1, NULL, NULL, NULL);
+				g_string_append (gs, g_strdup_printf ("&user=%s", locale));
+				break;
+			case SEARCH_CONSTRAINT_OWNED_BY_GROUP:
+				locale = g_locale_from_utf8 (constraint->data.text, -1, NULL, NULL, NULL);
+				g_string_append (gs, g_strdup_printf ("&group=%s", locale));
+				break;
+			case SEARCH_CONSTRAINT_OWNER_IS_UNRECOGNIZED:
+				g_string_append (gs, g_strdup ("&nouser"));
+				break;
+			case SEARCH_CONSTRAINT_FILE_IS_NOT_NAMED:
+				locale = g_locale_from_utf8 (constraint->data.text, -1, NULL, NULL, NULL);
+				g_string_append (gs, g_strdup_printf ("&notnamed=%s", locale));
+				break;
+			case SEARCH_CONSTRAINT_FILE_MATCHES_REGULAR_EXPRESSION:
+				locale = g_locale_from_utf8 (constraint->data.text, -1, NULL, NULL, NULL);
+				g_string_append (gs, g_strdup_printf ("&regex=%s", locale));
+				break;
+			case SEARCH_CONSTRAINT_SHOW_HIDDEN_FILES_AND_FOLDERS:
+				g_string_append (gs, g_strdup ("&hidden"));
+				break;
+			case SEARCH_CONSTRAINT_FOLLOW_SYMBOLIC_LINKS:
+				g_string_append (gs, g_strdup ("&follow"));
+				break;
+			case SEARCH_CONSTRAINT_SEARCH_OTHER_FILESYSTEMS:
+				g_string_append (gs, g_strdup ("&allmounts"));
+				break;
+			default:
+				break;
+			}
+		g_free (locale);
+		}		
+	}
+	g_string_append_c (gs, ')');
+	return g_string_free (gs, FALSE);
+}
+
+static gboolean
+setup_animation_image (void)
+{
+	gint	   width  = 0;
+	gint	   height = 0;
+	GError     *error = NULL;
+			
+	interface.current_animation_frame = DEFAULT_ANIMATION_FRAME - 1;
+
+	interface.pixbuf = gdk_pixbuf_new_from_file (GNOME_ICONDIR"/gnome-search-tool/gnome-search-tool-animation.png",
+	                                             &error);
+	
+	if (error) {
+		g_warning (_("The animation file is missing or invalid: %s"), error->message);		
+		g_error_free (error);
+		gtk_drawing_area_size (GTK_DRAWING_AREA (interface.drawing_area), 0, 0);
+		return FALSE;
+	}
+
+	width  = gdk_pixbuf_get_width (interface.pixbuf); 
+	height = gdk_pixbuf_get_height (interface.pixbuf); 
+
+	gtk_drawing_area_size (GTK_DRAWING_AREA (interface.drawing_area), width / TOTAL_ANIMATION_FRAMES, height);
+	interface.pixmap = gdk_pixmap_new (interface.drawing_area->window, width, height, -1);
+	gtk_widget_queue_draw (interface.drawing_area); 
+
+	return TRUE;
+}
+
+static gboolean
+animation_expose_event_cb (GtkWidget       *widget,
+                           GdkEventExpose  *event,
+                           gpointer        *data)
+{
+	gint width  = 0;
+	gint height = 0;
+
+	if (GDK_IS_DRAWABLE (interface.pixmap) == FALSE) {
+		return FALSE;
+	}
+
+	gdk_window_clear_area (widget->window,
+	                       event->area.x, event->area.y,
+	                       event->area.width, event->area.height);
+
+	gdk_gc_set_clip_rectangle (widget->style->fg_gc[widget->state], &event->area); 
+
+	gdk_drawable_get_size (interface.pixmap, &width, &height);
+
+	gdk_pixbuf_render_to_drawable_alpha (interface.pixbuf,
+	                                     GDK_DRAWABLE (widget->window),
+	                                     (width * interface.current_animation_frame) / TOTAL_ANIMATION_FRAMES, 0, 
+	                                     0, 0,
+	                                     width, height,
+	                                     GDK_PIXBUF_ALPHA_FULL, 255,
+	                                     GDK_RGB_DITHER_MAX,
+	                                     0, 0);
+
+	gdk_gc_set_clip_rectangle (widget->style->fg_gc[widget->state], NULL);
+
+        return FALSE;
+}
+
+static void
+start_animation (void)
+{
+	gchar *title = NULL;
+	
+	title = g_strconcat (_("Searching..."), " - ", _("Search for Files"), NULL);
+	gtk_window_set_title (GTK_WINDOW (interface.main_window), title);
+	
+	gtk_label_set_text (GTK_LABEL (interface.results_label), "");
+	search_command.animation_timeout = g_timeout_add (250, update_animation_timeout_cb, NULL);
+	
+	g_free (title);
+} 
+
+static void
+stop_animation (void)
+{
+	interface.current_animation_frame = DEFAULT_ANIMATION_FRAME - 1;
+	g_source_remove (search_command.animation_timeout);
+	gtk_widget_queue_draw (interface.drawing_area);
+} 
+
+gboolean
+update_animation_timeout_cb (gpointer data)
+{
+	static gboolean in_forward_progress = TRUE;
+	
+	if (in_forward_progress == TRUE) {
+		interface.current_animation_frame++;
+		if (interface.current_animation_frame >= (TOTAL_ANIMATION_FRAMES - 1)) {
+			in_forward_progress = !in_forward_progress;
+		}
+	}
+	else {
+		interface.current_animation_frame--;
+		if (interface.current_animation_frame <= 0) {
+			in_forward_progress = !in_forward_progress;
+		}
+	}
+		      
+	gtk_widget_queue_draw (interface.drawing_area);
+
+	return TRUE;
+}
+
 void
 define_popt_descriptions (void) 
 {
@@ -1035,7 +1221,7 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 		gchar *search_status = g_strdup ("");
 		
 		if (search_data->running == MAKE_IT_STOP) {
-			search_status = g_strdup (_("(aborted)"));
+			search_status = g_strdup (_("(stopped)"));
 		}
 		
 		search_data->lock = FALSE;
@@ -1056,16 +1242,20 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 		else {
 			status_bar_string = g_strdup_printf (_("%d files found"), total_files);
 		}
-		status_bar_string = g_strconcat (status_bar_string, " ", search_status, NULL);
+		
+		if (strlen(search_status) > 0) {
+			status_bar_string = g_strconcat (status_bar_string, " ", search_status, NULL);
+		}
+		gtk_label_set_text (GTK_LABEL (interface.results_label), status_bar_string);
+		
+		status_bar_string = g_strconcat (status_bar_string, " - ", _("Search for Files"), NULL);
+		gtk_window_set_title (GTK_WINDOW (interface.main_window), status_bar_string);
 
-		gnome_appbar_pop (GNOME_APPBAR (interface.status_bar));
-		gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (interface.progress_bar), 0.0);
-		gnome_appbar_push (GNOME_APPBAR (interface.status_bar), status_bar_string);
-		g_source_remove (search_data->timeout);
+		stop_animation ();
 
 		gtk_window_set_default (GTK_WINDOW(interface.main_window), interface.find_button);
 		gtk_widget_set_sensitive (interface.additional_constraints, TRUE);
-		gtk_widget_set_sensitive (interface.disclosure, TRUE);
+		gtk_widget_set_sensitive (interface.checkbutton, TRUE);
 		gtk_widget_set_sensitive (interface.table, TRUE);
 		gtk_widget_set_sensitive (interface.find_button, TRUE);
 		gtk_widget_hide (interface.stop_button);
@@ -1157,19 +1347,17 @@ handle_search_command_stderr_io (GIOChannel 	*ioc,
 					error_msgs = g_string_append (error_msgs, 
 				     		_("\n... Too many errors to display ..."));
 				}
-		
-				dialog = gtk_message_dialog_new (GTK_WINDOW (interface.main_window),
-					GTK_DIALOG_DESTROY_WITH_PARENT,
-					GTK_MESSAGE_ERROR,
-					GTK_BUTTONS_OK,
-					error_msgs->str);
-
+				
+				dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
+				                                     GTK_DIALOG_DESTROY_WITH_PARENT,
+								     GTK_BUTTONS_OK,
+				                                     _("Error while searching for files"),
+				                                     error_msgs->str);
+				
 				g_signal_connect (G_OBJECT (dialog),
 					"response",
 					G_CALLBACK (gtk_widget_destroy), NULL);
-		
-				gtk_window_set_title (GTK_WINDOW (dialog), _("Search Errors"));	
-				gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+				
 				gtk_widget_show (dialog);
 	
 			}
@@ -1192,21 +1380,19 @@ spawn_search_command (gchar *command)
 	gint        child_stdout;
 	gint        child_stderr;
 	
+	start_animation ();
+	
 	if (!g_shell_parse_argv (command, NULL, &argv, &error)) {
 		GtkWidget *dialog;
 
-		gnome_appbar_pop (GNOME_APPBAR (interface.status_bar));
-		gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (interface.progress_bar), 0.0);
-		gnome_appbar_push (GNOME_APPBAR (interface.status_bar), "");
-		g_source_remove (search_command.timeout);
-		
-		dialog = gtk_message_dialog_new(GTK_WINDOW (interface.main_window), 
-						GTK_DIALOG_DESTROY_WITH_PARENT, 
-						GTK_MESSAGE_ERROR, 
-						GTK_BUTTONS_OK,
-						error->message);
-						
-		gtk_window_set_title (GTK_WINDOW (dialog), _("Search for Files Error"));
+		stop_animation ();
+
+		dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
+		                                     GTK_DIALOG_DESTROY_WITH_PARENT,
+						     GTK_BUTTONS_OK,
+					             _("Error parsing the search command"),
+					             (error != NULL) ? error->message : "");
+
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
 		g_error_free (error);
@@ -1219,18 +1405,14 @@ spawn_search_command (gchar *command)
 				       &child_stderr, &error)) {
 		GtkWidget *dialog;
 		
-		gnome_appbar_pop (GNOME_APPBAR (interface.status_bar));
-		gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (interface.progress_bar), 0.0);
-		gnome_appbar_push (GNOME_APPBAR (interface.status_bar), "");
-		g_source_remove (search_command.timeout);
-		
-		dialog = gtk_message_dialog_new(GTK_WINDOW (interface.main_window), 
-						GTK_DIALOG_DESTROY_WITH_PARENT, 
-						GTK_MESSAGE_ERROR, 
-						GTK_BUTTONS_OK,
-						error->message);
+		stop_animation ();
+						
+		dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
+		                                     GTK_DIALOG_DESTROY_WITH_PARENT,
+						     GTK_BUTTONS_OK,
+					             _("Error running the search command"),
+					             (error != NULL) ? error->message : "");
 
-		gtk_window_set_title (GTK_WINDOW (dialog), _("Search for Files Error"));
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
 		g_error_free (error);
@@ -1247,7 +1429,7 @@ spawn_search_command (gchar *command)
 	gtk_widget_set_sensitive (interface.find_button, FALSE);
 	gtk_widget_set_sensitive (interface.results, TRUE);
 	gtk_widget_set_sensitive (interface.additional_constraints, FALSE);
-	gtk_widget_set_sensitive (interface.disclosure, FALSE);
+	gtk_widget_set_sensitive (interface.checkbutton, FALSE);
 	gtk_widget_set_sensitive (interface.table, FALSE);
 
 	gtk_tree_view_scroll_to_point (GTK_TREE_VIEW(interface.tree), 0, 0);
@@ -1372,19 +1554,23 @@ add_constraint (gint constraint_id, gchar *value, gboolean show_constraint)
 {
 	SearchConstraint *constraint = g_new(SearchConstraint,1);
 	GtkWidget *widget;
-	
+
 	if (show_constraint == TRUE) {
 		if (GTK_WIDGET_VISIBLE (interface.additional_constraints) == FALSE) {
-			g_signal_emit_by_name (G_OBJECT(interface.disclosure), "clicked", 0);
+			g_signal_emit_by_name (G_OBJECT(interface.checkbutton), "clicked", 0);
 			gtk_widget_show (interface.additional_constraints);
 		}
 	} 
 	
-	interface.geometry.min_height += 35; 
-	gtk_window_set_geometry_hints (GTK_WINDOW(interface.main_window), 
-				       GTK_WIDGET(interface.main_window),
-				       &interface.geometry, GDK_HINT_MIN_SIZE);
+	interface.geometry.min_height += 35;
 	
+	if (GTK_WIDGET_VISIBLE (interface.additional_constraints) == TRUE) {
+		gtk_window_set_geometry_hints (GTK_WINDOW (interface.main_window), 
+		                               GTK_WIDGET (interface.main_window),
+		                               &interface.geometry, 
+		                               GDK_HINT_MIN_SIZE);
+	}
+		
 	constraint->constraint_id = constraint_id;
 	set_constraint_info_defaults (constraint);
 	set_constraint_gconf_boolean (constraint->constraint_id, TRUE);
@@ -1447,15 +1633,23 @@ create_search_results_section (void)
 {
 	GtkWidget 	  *label;
 	GtkWidget 	  *vbox;
+	GtkWidget	  *hbox;
 	GtkWidget	  *window;	
 	GtkTreeViewColumn *column;	
 	GtkCellRenderer   *renderer;
 	
 	vbox = gtk_vbox_new (FALSE, 6);	
 	
+	hbox = gtk_hbox_new (FALSE, 12);
+	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+	
 	label = gtk_label_new_with_mnemonic (_("S_earch results:"));
 	g_object_set (G_OBJECT(label), "xalign", 0.0, NULL);
-	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
+	
+	interface.results_label = gtk_label_new (NULL);
+	g_object_set (G_OBJECT (interface.results_label), "xalign", 1.0, NULL);
+	gtk_box_pack_start (GTK_BOX (hbox), interface.results_label, FALSE, FALSE, 0);
 	
 	window = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW(window), GTK_SHADOW_NONE);	
@@ -1473,7 +1667,7 @@ create_search_results_section (void)
 					      G_TYPE_DOUBLE,
 					      G_TYPE_STRING,
 					      G_TYPE_STRING,
-					      G_TYPE_STRING,
+					      G_TYPE_DOUBLE,
 					      G_TYPE_BOOLEAN);
 	
 	interface.tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL(interface.model));
@@ -1594,15 +1788,16 @@ create_search_results_section (void)
 GtkWidget *
 create_main_window (void)
 {
+	GtkTargetEntry  drag_types[] = { { "text/uri-list", 0, 0 } };
 	gchar 		*locale_string;
 	gchar		*utf8_string;
 	GtkWidget 	*hbox;	
+	GtkWidget	*vbox;
 	GtkWidget 	*entry;
 	GtkWidget	*label;
 	GtkWidget 	*folder_entry;
 	GtkWidget 	*button;
 	GtkWidget 	*window;
-	GtkWidget	*image;
 
 	window = gtk_vbox_new (FALSE, 6);	
 	gtk_container_set_border_width (GTK_CONTAINER(window), 12);
@@ -1610,8 +1805,32 @@ create_main_window (void)
 	hbox = gtk_hbox_new (FALSE, 12);
 	gtk_box_pack_start (GTK_BOX(window), hbox, FALSE, FALSE, 0);
 	
-	image = gtk_image_new_from_stock (GNOME_SEARCH_TOOL_STOCK, gsearchtool_icon_size);
-	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
+	vbox = gtk_vbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, 0);
+
+	interface.drawing_area = gtk_drawing_area_new ();
+	gtk_box_pack_start (GTK_BOX (vbox), interface.drawing_area, TRUE, FALSE, 0);
+
+	gtk_drawing_area_size (GTK_DRAWING_AREA (interface.drawing_area),
+	                       DEFAULT_ANIMATION_WIDTH,
+			       DEFAULT_ANIMATION_HEIGHT);
+			  
+	gtk_drag_source_set (interface.drawing_area, 
+			     GDK_BUTTON1_MASK,
+			     drag_types, 
+			     G_N_ELEMENTS (drag_types), 
+			     GDK_ACTION_COPY);
+			     
+	gtk_drag_source_set_icon_stock (interface.drawing_area,
+	                                GTK_STOCK_FIND);
+			  
+	g_signal_connect (G_OBJECT (interface.drawing_area), 
+			  "drag_data_get",
+			  G_CALLBACK (drag_data_animation_cb), 
+			  interface.main_window);
+
+	g_signal_connect (interface.drawing_area, "expose-event",
+			  G_CALLBACK (animation_expose_event_cb), NULL);
 	
 	interface.table = gtk_table_new (2, 2, FALSE);
 	gtk_table_set_row_spacings (GTK_TABLE(interface.table), 6);
@@ -1633,8 +1852,8 @@ create_main_window (void)
 	if (GTK_IS_ACCESSIBLE (gtk_widget_get_accessible(interface.file_is_named_entry)))
 	{
 		interface.is_gail_loaded = TRUE;
-		add_atk_namedesc (interface.file_is_named_entry, _("File Name Entry"), _("Enter the file name you want to search"));
-		add_atk_namedesc (entry, _("File Name Entry"), _("Enter the file name you want to search"));
+		add_atk_namedesc (interface.file_is_named_entry, _("Name Contains Entry"), _("Enter the file name you want to search"));
+		add_atk_namedesc (entry, _("Name Contains Entry"), _("Enter the file name you want to search"));
 		add_atk_relation (interface.file_is_named_entry, GTK_WIDGET(label), ATK_RELATION_LABELLED_BY);
 	}	
      
@@ -1661,8 +1880,8 @@ create_main_window (void)
 	
 	if (interface.is_gail_loaded)
 	{ 
-		add_atk_namedesc (GTK_WIDGET(folder_entry), _("Starting folder entry"), _("Enter the folder name where you want to start the search"));
-		add_atk_namedesc (GTK_WIDGET(entry), _("Starting folder entry"), _("Enter the folder name where you want to start the search"));
+		add_atk_namedesc (GTK_WIDGET(folder_entry), _("Look in Folder Entry"), _("Enter the folder name where you want to start the search"));
+		add_atk_namedesc (GTK_WIDGET(entry), _("Look in Folder Entry"), _("Enter the folder name where you want to start the search"));
 		add_atk_relation (folder_entry, GTK_WIDGET(label), ATK_RELATION_LABELLED_BY); 
 	}
 	
@@ -1680,25 +1899,27 @@ create_main_window (void)
 	gtk_entry_set_text (GTK_ENTRY(entry), utf8_string);
 	g_free (locale_string);
 	g_free (utf8_string);
-
-	interface.disclosure = cddb_disclosure_new (_("Additional Options"),
-						    _("Additional Options"));
-	gtk_box_pack_start (GTK_BOX(window), interface.disclosure, FALSE, FALSE, 0);
 	
+	interface.checkbutton = gtk_check_button_new_with_mnemonic (_("Show more _options"));
+	gtk_box_pack_start (GTK_BOX(window), interface.checkbutton, FALSE, FALSE, 0);
+	g_signal_connect (G_OBJECT (interface.checkbutton),"clicked",
+			  G_CALLBACK (click_check_button_cb), NULL);
+			  
 	interface.additional_constraints = create_additional_constraint_section ();
-  	cddb_disclosure_set_container (CDDB_DISCLOSURE(interface.disclosure), interface.additional_constraints);
-
 	gtk_box_pack_start (GTK_BOX(window), GTK_WIDGET(interface.additional_constraints), FALSE, FALSE, 0);
 	
+	vbox = gtk_vbox_new (FALSE, 12);
+	gtk_box_pack_start (GTK_BOX (window), vbox, TRUE, TRUE, 0);
+	
 	interface.results = create_search_results_section ();
-	gtk_widget_set_sensitive (GTK_WIDGET(interface.results), FALSE);
-	gtk_box_pack_start (GTK_BOX(window), interface.results, TRUE, TRUE, 0);
+	gtk_widget_set_sensitive (GTK_WIDGET (interface.results), FALSE);
+	gtk_box_pack_start (GTK_BOX (vbox), interface.results, TRUE, TRUE, 0);
 	
 	hbox = gtk_hbutton_box_new ();
-	gtk_button_box_set_layout (GTK_BUTTON_BOX(hbox), GTK_BUTTONBOX_END);
-	gtk_box_pack_start (GTK_BOX(window), hbox, FALSE, FALSE, 0);
+	gtk_button_box_set_layout (GTK_BUTTON_BOX (hbox), GTK_BUTTONBOX_END);
+	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-	gtk_box_set_spacing (GTK_BOX(hbox), 6);
+	gtk_box_set_spacing (GTK_BOX(hbox), 10);
 	button = gtk_button_new_from_stock (GTK_STOCK_HELP);
 	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 	gtk_box_pack_start (GTK_BOX(hbox), button, FALSE, FALSE, 0);
@@ -1744,7 +1965,7 @@ register_gsearchtool_icon (GtkIconFactory *factory)
 
 	source = gtk_icon_source_new ();
 
-	gtk_icon_source_set_filename (source, GNOME_ICONDIR"/gnome-searchtool.png");
+	gtk_icon_source_set_filename (source, GNOME_ICONDIR"/"GNOME_SEARCH_TOOL_ICON);
 
 	icon_set = gtk_icon_set_new ();
 	gtk_icon_set_add_source (icon_set, source);
@@ -1774,7 +1995,7 @@ gsearchtool_init_stock_icons ()
 }
 
 void
-set_clone_command (gint *argcp, gchar ***argvp, gpointer client_data)
+set_clone_command (gint *argcp, gchar ***argvp, gpointer client_data, gboolean escape_values)
 {
 	gchar **argv;
 	gchar *file_is_named_utf8;
@@ -1791,13 +2012,17 @@ set_clone_command (gint *argcp, gchar ***argvp, gpointer client_data)
 	file_is_named_utf8 = (gchar *) gtk_entry_get_text (GTK_ENTRY(gnome_entry_gtk_entry (GNOME_ENTRY(interface.file_is_named_entry))));
 	file_is_named_locale = g_locale_from_utf8 (file_is_named_utf8 != NULL ? file_is_named_utf8 : "" , 
 	                                           -1, NULL, NULL, NULL);
-	argv[i++] = g_strdup_printf ("--named=%s", file_is_named_locale);
+	argv[i++] = (escape_values == TRUE) ? 
+	            g_strdup_printf ("--named=\"%s\"", g_strescape (file_is_named_locale, NULL)) : 
+		    g_strdup_printf ("--named=%s", file_is_named_locale);	
 	g_free (file_is_named_locale);
 
 	look_in_folder_utf8 = gnome_file_entry_get_full_path (GNOME_FILE_ENTRY(interface.look_in_folder_entry), FALSE);
 	look_in_folder_locale = g_locale_from_utf8 (look_in_folder_utf8 != NULL ? look_in_folder_utf8 : "", 
 	                                            -1, NULL, NULL, NULL);
-	argv[i++] = g_strdup_printf ("--path=%s", look_in_folder_locale);
+	argv[i++] = (escape_values == TRUE) ? 
+	            g_strdup_printf ("--path=\"%s\"", g_strescape (look_in_folder_locale, NULL)) : 
+		    g_strdup_printf ("--path=%s", look_in_folder_locale);
 	g_free (look_in_folder_locale);
 
 	if (GTK_WIDGET_VISIBLE(interface.additional_constraints) == TRUE) {
@@ -1808,7 +2033,9 @@ set_clone_command (gint *argcp, gchar ***argvp, gpointer client_data)
 			switch (constraint->constraint_id) {
 			case SEARCH_CONSTRAINT_CONTAINS_THE_TEXT:
 				locale = g_locale_from_utf8 (constraint->data.text, -1, NULL, NULL, NULL);
-				argv[i++] = g_strdup_printf ("--contains=%s", locale);
+				argv[i++] = (escape_values == TRUE) ? 
+				            g_strdup_printf ("--contains=\"%s\"", g_strescape (locale, NULL)) : 
+					    g_strdup_printf ("--contains=%s", locale);
 				break;
 			case SEARCH_CONSTRAINT_DATE_MODIFIED_BEFORE:
 				argv[i++] = g_strdup_printf ("--mtimeless=%d", constraint->data.time);
@@ -1827,22 +2054,30 @@ set_clone_command (gint *argcp, gchar ***argvp, gpointer client_data)
 				break;
 			case SEARCH_CONSTRAINT_OWNED_BY_USER:
 				locale = g_locale_from_utf8 (constraint->data.text, -1, NULL, NULL, NULL);
-				argv[i++] = g_strdup_printf ("--user=%s", locale);
+				argv[i++] = (escape_values == TRUE) ? 
+				            g_strdup_printf ("--user=\"%s\"", g_strescape (locale, NULL)) : 
+					    g_strdup_printf ("--user=%s", locale);
 				break;
 			case SEARCH_CONSTRAINT_OWNED_BY_GROUP:
 				locale = g_locale_from_utf8 (constraint->data.text, -1, NULL, NULL, NULL);
-				argv[i++] = g_strdup_printf ("--group=%s", locale);
+				argv[i++] = (escape_values == TRUE) ? 
+				            g_strdup_printf ("--group=\"%s\"", g_strescape (locale, NULL)) : 
+					    g_strdup_printf ("--group=%s", locale);
 				break;
 			case SEARCH_CONSTRAINT_OWNER_IS_UNRECOGNIZED:
 				argv[i++] = g_strdup ("--nouser");
 				break;
 			case SEARCH_CONSTRAINT_FILE_IS_NOT_NAMED:
 				locale = g_locale_from_utf8 (constraint->data.text, -1, NULL, NULL, NULL);
-				argv[i++] = g_strdup_printf ("--notnamed=%s", locale);
+				argv[i++] = (escape_values == TRUE) ? 
+				            g_strdup_printf ("--notnamed=\"%s\"", g_strescape (locale, NULL)) : 
+					    g_strdup_printf ("--notnamed=%s", locale);
 				break;
 			case SEARCH_CONSTRAINT_FILE_MATCHES_REGULAR_EXPRESSION:
 				locale = g_locale_from_utf8 (constraint->data.text, -1, NULL, NULL, NULL);
-				argv[i++] = g_strdup_printf ("--regex=%s", locale);
+				argv[i++] = (escape_values == TRUE) ? 
+				            g_strdup_printf ("--regex=\"%s\"", g_strescape (locale, NULL)) : 
+					    g_strdup_printf ("--regex=%s", locale);
 				break;
 			case SEARCH_CONSTRAINT_SHOW_HIDDEN_FILES_AND_FOLDERS:
 				argv[i++] = g_strdup ("--hidden");
@@ -1868,7 +2103,7 @@ handle_gconf_settings (void)
 {
 	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/show_additional_options") == TRUE) {
 		if (GTK_WIDGET_VISIBLE (interface.additional_constraints) == FALSE) {
-			g_signal_emit_by_name (G_OBJECT(interface.disclosure), "clicked", 0);
+			g_signal_emit_by_name (G_OBJECT(interface.checkbutton), "clicked", 0);
 			gtk_widget_show (interface.additional_constraints);
 		}
 	}
@@ -1939,8 +2174,8 @@ main (int 	argc,
 	GtkWidget    *window;
 
 	global_gconf_client = NULL;
-	interface.geometry.min_height = 310;
-	interface.geometry.min_width  = 422;
+	interface.geometry.min_height = MINIMUM_WINDOW_HEIGHT;
+	interface.geometry.min_width  = MINIMUM_WINDOW_WIDTH;
 
 	/* initialize the i18n stuff */
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
@@ -1960,7 +2195,7 @@ main (int 	argc,
 					  GNOME_PARAM_APP_DATADIR, DATADIR,  
 					  NULL);
 	gsearchtool_init_stock_icons ();				  
-	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-searchtool.png");
+	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/"GNOME_SEARCH_TOOL_ICON);
 
 	if (!bonobo_init_full (&argc, argv, bonobo_activation_orb_get (), NULL, NULL))
 		g_error (_("Cannot initialize bonobo."));
@@ -1984,8 +2219,6 @@ main (int 	argc,
 	window = create_main_window ();
 	gnome_app_set_contents (GNOME_APP(interface.main_window), window);
 
-	setup_app_progress_bar ();
-
 	gtk_window_set_geometry_hints (GTK_WINDOW(interface.main_window), GTK_WIDGET(interface.main_window),
 				       &interface.geometry, GDK_HINT_MIN_SIZE);
 
@@ -2005,6 +2238,9 @@ main (int 	argc,
 	gtk_widget_show (interface.main_window);
 	
 	interface.icon_theme = gnome_icon_theme_new ();
+	gnome_icon_theme_set_allow_svg (interface.icon_theme, TRUE);
+
+	setup_animation_image ();
 	
 	if (handle_popt_args () == FALSE) {
 		handle_gconf_settings (); 
