@@ -179,7 +179,6 @@ GnomeUIInfo main_menu[] = {
  */
 	
 GtkWidget *app = NULL;
-static GtkWidget *viewport;
 GtkLabel *date_label = NULL;
 
 GList *regexp_db = NULL, *descript_db = NULL, *actions_db = NULL;
@@ -249,7 +248,6 @@ static gboolean
 restore_session (void)
 {
    Log *tl;
-   gint i, logcnt = 0;
 
    /* closing the log file opened by default */
    CloseLog (loglist[0]);
@@ -278,6 +276,7 @@ restore_session (void)
             g_free (f);
       }
    } while ((next_opt = poptGetNextOpt (poptCon)) != -1);
+   return TRUE;
 }
 
 static gint
@@ -374,10 +373,8 @@ InitApp ()
 void
 CreateMainWin ()
 {
-   GtkWidget *w, *vbox, *table, *hbox, *hbox_date;
-   GtkWidget *padding;
+   GtkWidget *vbox, *hbox, *hbox_date;
    GtkLabel *label;
-   GtkObject *adj;
    GtkAllocation req_size;
    GtkTreeStore *tree_store;
    GtkTreeSelection *selection;
@@ -391,14 +388,13 @@ CreateMainWin ()
 
    /* Create App */
 
-   if ((curlog != NULL) && (numlogs))
+   if ((curlog != NULL) && (curlog->name != NULL) && (numlogs))
        window_title = g_strdup_printf ("%s - %s", curlog->name, APP_NAME);
    else
        window_title = g_strdup_printf (APP_NAME);
    app = gnome_app_new ("gnome-system-log", window_title);
    g_free (window_title);
 
-   gtk_container_set_border_width ( GTK_CONTAINER (app), 0);
    gtk_window_set_default_size ( GTK_WINDOW (app), LOG_CANVAS_W, LOG_CANVAS_H);
    req_size.x = req_size.y = 0;
    req_size.width = 400;
@@ -410,7 +406,8 @@ CreateMainWin ()
    /* Create menus */
    gnome_app_create_menus (GNOME_APP (app), main_menu);
 
-   vbox = gtk_vbox_new (FALSE, 0);
+   vbox = gtk_vbox_new (FALSE, 6);
+   gtk_container_set_border_width ( GTK_CONTAINER (vbox), 6);
    gnome_app_set_contents (GNOME_APP (app), vbox);
 
    if (numlogs < 2)
@@ -436,11 +433,11 @@ CreateMainWin ()
    /* Add Tree View Columns */
    for (i = 0; column_titles[i]; i++) {
         renderer = gtk_cell_renderer_text_new ();
-        column = gtk_tree_view_column_new_with_attributes (column_titles[i],
+        column = gtk_tree_view_column_new_with_attributes (_(column_titles[i]),
                     renderer, "text", i, NULL);
         gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_AUTOSIZE); 
         gtk_tree_view_column_set_resizable (column, TRUE);
-        gtk_tree_view_column_set_spacing (column, GNOME_PAD_SMALL);
+        gtk_tree_view_column_set_spacing (column, 6);
         gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    }
 
@@ -458,15 +455,12 @@ CreateMainWin ()
                      G_CALLBACK (handle_row_activation_cb), NULL);
 
    /* Create status area at bottom */
-   hbox = gtk_hbox_new (FALSE, 2);
-   gtk_container_set_border_width ( GTK_CONTAINER (hbox), 3);
+   hbox = gtk_hbox_new (FALSE, 12);
 
-   hbox_date = gtk_hbox_new (FALSE, 2);
-   gtk_container_set_border_width ( GTK_CONTAINER (hbox_date), 3);
+   hbox_date = gtk_hbox_new (FALSE, 12);
 
    date_label = (GtkLabel *)gtk_label_new ("");
    gtk_widget_show (GTK_WIDGET (date_label));
-   /* gtk_widget_set_size_request (GTK_WIDGET (label), 60, -1); */
    gtk_box_pack_end (GTK_BOX (hbox_date), GTK_WIDGET (date_label), 
 		     TRUE, TRUE, 0);
 
@@ -866,7 +860,7 @@ void SetDefaultUserPrefs(UserPrefsStruct *prefs)
 	gchar *logfile = NULL;
 	struct stat filestat;
 	
-	logfile = gconf_client_get_string (client, "/apps/logview/logfile", NULL);
+	logfile = gconf_client_get_string (client, "/apps/gnome-system-log/logfile", NULL);
 	if (logfile != NULL && strcmp (logfile, "")) {
 		prefs->logfile = g_strdup (logfile);
 		g_free (logfile);
@@ -882,7 +876,6 @@ void SetDefaultUserPrefs(UserPrefsStruct *prefs)
 		else
 			prefs->logfile = NULL;
 	}
-	
 }
 
 void SaveUserPrefs(UserPrefsStruct *prefs)
