@@ -21,7 +21,6 @@
 
 
 #include <config.h>
-
 #include <gnome.h>
 
 #include "logview.h"
@@ -33,42 +32,6 @@ static gboolean queue_err_messages = FALSE;
 static GList *msg_queue = NULL;
 
 
-/* ----------------------------------------------------------------------
-   NAME:	ButtonWithPixmap
-   DESCRIPTION:	
-   ---------------------------------------------------------------------- */
-
-GtkWidget
-*ButtonWithPixmap (char **xpmdata, int w, int h)
-{
-   GtkWidget *button, *pixmapwid, *alignment;
-   GdkPixmap *pixmap;
-   GdkBitmap *mask;
-   GtkStyle *style;
-
-   button = gtk_button_new ();
-   gtk_container_border_width (GTK_CONTAINER (button), 0);
-   gtk_widget_set_style (button, cfg->main_style);
-   gtk_widget_show (button);
-
-   style = gtk_widget_get_style (button);
-
-   pixmap = gdk_pixmap_create_from_xpm_d (button->window, &mask,
-					  &style->bg[GTK_STATE_NORMAL],
-					  xpmdata);
-   pixmapwid = gtk_pixmap_new (pixmap, mask);
-   alignment = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
-   gtk_container_border_width (GTK_CONTAINER (alignment), 0);
-   if (w > 0 && h > 0)
-     gtk_widget_set_usize (alignment, w, h);
-   gtk_container_add (GTK_CONTAINER (button), alignment);
-   gtk_container_add (GTK_CONTAINER (alignment), pixmapwid);
-   gtk_widget_show (pixmapwid);
-   gtk_widget_show (alignment);
-
-   return button;
-}
-
 static void
 MakeErrorDialog (const char *msg)
 {
@@ -90,7 +53,7 @@ MakeErrorDialog (const char *msg)
 void
 ShowErrMessage (const char *msg)
 {
-  printf(_("Error: [%s]\n"), msg);
+  DB (printf(_("Error: [%s]\n"), msg));
 
   if (queue_err_messages) {
 	  msg_queue = g_list_append (msg_queue, g_strdup (msg));
@@ -131,3 +94,20 @@ ShowQueuedErrMessages (void)
 		g_string_free (gs, TRUE);
 	}
 }
+
+char *
+LocaleToUTF8 (const char *in)
+{
+	/* FIXME: we could guess the language from the line how we guessed
+	 * the month and can we get this to utf8 correctly even if it's not in
+	 * the current encoding */
+	char *out = g_locale_to_utf8 (in, -1, NULL, NULL, NULL);
+	if (out == NULL) {
+		if (g_utf8_validate (in, -1, NULL))
+			return g_strdup (in);
+		else
+			return g_strdup ("?");
+	} else {
+		return out;
+	}
+}
